shape_view

Function shape_view 

pub fn shape_view(
    cx: &mut Cx,
    shape_value: &Value,
    value: &Expr,
    counterexample: &Expr,
) -> Result<Expr>
Render a Shape inspected against a matching value and a counterexample that should fail, into one Scene.